@@ -21,12 +21,13 @@ our @V = (
           ul({-id => 'menu'},
             li(a({-href => '/'},            "home")),
             li(a({-href => '/?foo=1&bar=2&baz=5'}, "home + cgi")),
-            li(a({-href => '/@count'},      "count"), span('[RESTless]')),
+            li(a({-href => '/@count'},      "count"), span('[RESTless] [Reload the page to watch the counter increment]')),
             li(a({-href => '/~beppu'},      "profile")),
             li(a({-href => '/~beppu.json'}, "profile.json")),
             li(a({-href => '/env'},         "env")),
             li(a({-href => '/env.json'},    "env.json")),
-            li(a({-href => '/rubygems'},    "redirect to rubygems")),
+            li(a({-href => '/rubygems'},    "redirect to ruby's gem_server on port 8808")),
+            li(a({-href => '/pod/'},        "PODServer has been mounted on /pod")),
             li(a({-href => '/droids-you-are-looking-for'}, "404")),
           ),
         ),
